@@ -1,4 +1,5 @@
 import json
+import os
 import re
 from datetime import datetime
 from typing import Optional, List
@@ -16,7 +17,7 @@ from django.dispatch import receiver
 from .log import NotifyErrorLog
 from .user_list import NotifyUserList
 from .category import NotifyCategory
-from .choices import TYPE, STATE
+from .choices import TYPE, STATE, StatusMessage
 from .file import NotifyFile
 from .template import NotifyTemplate
 from ..exceptions import IsInstanceException
@@ -62,6 +63,8 @@ class Notify(NotifyMixin, UserNotifyMixin):
     created_at = models.DateTimeField('Дата создания', auto_now_add=True)
     sent_at = models.DateTimeField('Дата отправки', blank=True, null=True)
 
+    is_delete_after = models.BooleanField(default=False, verbose_name='Удалять после отправки')
+
     objects = Manager()
 
     def __str__(self):
@@ -97,7 +100,10 @@ class Notify(NotifyMixin, UserNotifyMixin):
         elif self.type == TYPE.WHATSAPP:
             WhatsAppClient.send_whatsapp(self)
 
-        self.save()
+        if self.is_delete_after and self.state == STATE.DELIVERED:
+            self._delete_notify()
+        else:
+            self.save()
 
     @staticmethod
     def send(event: int, context: dict, user: User = None, email: str = None, phone: str = None,  # noqa: C901
@@ -222,6 +228,7 @@ class Notify(NotifyMixin, UserNotifyMixin):
                 data_json=data_json,
                 send_at=notify_send,
                 room_name=room_name,
+                is_delete_after=template.is_delete_after,
                 **kwargs
             )
             if notify_users_lists.exists():
@@ -266,18 +273,22 @@ class Notify(NotifyMixin, UserNotifyMixin):
         log.save()
 
     def get_format_state(self):
-        if self.state == STATE.WAIT:
-            return format_html('<span style="color:orange;">В ожидании</span>')
-        elif self.state == STATE.DELIVERED:
-            return format_html('<span style="color:green;">Отправлено</span>')
-        elif self.state == STATE.REJECTED:
-            return format_html('<span style="color:red;">Отклонено</span>')
-        elif self.state == STATE.DISABLED:
-            return format_html('<span style="color:red;">Отправка запрещена</span>')
-        return format_html('<span style="color:black;">Неизвестный статус</span>')
+        undefined = '<span style="color:black;">Неизвестный статус</span>'
+        status: str = StatusMessage.STATUS.get(self.state, undefined)
+        return format_html(status)
 
     get_format_state.short_description = 'Статус'
 
+    def _delete_notify(self) -> None:
+        files = self.files.all()
+        if files.exists():
+            for file in files:
+                file_path = f'{settings.MEDIA_ROOT}/{file.file}'
+                if os.path.isfile(file_path):
+                    os.remove(file_path)
+            files.delete()
+        self.delete()
+
     class Meta:
         verbose_name = 'Уведомление'
         verbose_name_plural = 'Уведомления'
